<?php


/**
 * this file contains all the implementations of signit hook operations 
 * for the default operation of the module
 */
 
 
/* ******************************************** */
/* Message functions */
/* ******************************************** */

/**
 * implementation of the hook_signit_messaging
 */
function signit_signit_message($op, $data = array()){
  switch ($op) {
    case 'admin':
      return signit_signit_message_admin();
    break;
    case 'create':
      return signit_signit_message_create($data);
  } 
}

/**
 * generates the form for admining hook_signit_targets
 */
function signit_signit_message_admin() {
  $form['signit_message_control'] = array(
    '#type' => 'checkbox',
    '#title' => 'SignIt creators can set the email options of their signit',
    '#default_value' => variable_get('signit_message_control', true)  
  );
  return $form;
}

/**
 * generates the form for creating hook_signit_targets
 */
function signit_signit_message_create($signit){
  $form['signit_email_from'] = array(
    '#type' => 'textfield',
    '#title' => t('Email from'),
    '#default_value' => $signit['email_from'] ? $signit['email_from']: variable_get("site_mail", null),
    '#description'   => t('Enter the email address that will appear in the "From: " header of sent messages. This is <em>only</em> used when sending a list of signatures.'),
  );
  $form['signit_email_subject_set'] = array(
    '#type' => 'checkbox',
    '#title' => t('Allow users to set email subject.'),
    '#options' => array('Enabled'),
    '#default_value' => $signit['email_subject_set'] ? 1 : 0,
    '#description' => t('If this is not set, the subject will be populated by the below value'), 
  );
  
  // signit message subject 
  $form['signit_email_subject'] = array(
    '#type'          => 'textfield',
    '#title'         => t('Email subject'),
    '#default_value' => $signit['email_subject'] ? $signit['email_subject'] : "My SignIt ",
    '#description'   => t('Subject of auto-response email message to be sent.'),
  ); 
  
  // signit message body
  $form['signit_message_filter']['signit_message'] = array(
    '#type'          => 'textarea',
    '#title'         => t('Email message'),
    '#default_value' => $signit['message'],
    '#description'   => t('Body of auto-response email message to be sent. Please note, changes to this do not effect already collected signatures.'),
  );
  // add a filter form to to the body
  $form['signit_message_filter']['signit_message_format'] = filter_form($signit['message_format'], null, array('signit_message_filter'));

  $form['signit_personal_message'] = array(
    '#type' => 'checkbox',
    '#title' => t('Allow users to add personal messages.'),
    '#options' => array('Enabled'),
    '#default_value' => $signit['personal_message'] ? 1 : 0,
    '#description' => t('Gives user the ability to add a personal message to the email template. ')
  );
  
  $form['signit_comment_allow'] = array(
    '#type' => 'checkbox',
    '#title' => t('Allow users to add a comment.'),
    '#options' => array('Enabled'),
    '#default_value' => $signit['comment_allow'] ? 1 : 0,
    '#description' => t('Gives user the ability to leave a comment along with their message. This can be displayed on the list of signatures.')
  );
  
  $form['signit_comment_allow_html'] = array(
    '#type' => 'checkbox',
    '#title' => t('Allow HTML in comment form.'),
    '#options' => array('Enabled'),
    '#default_value' => $signit['comment_allow_html'] ? 1 : 0,
    '#description' => t('If this is checked, non-anonymous users will be allowed to have HTML tags in the comment form. Anonymous users are <em>never</em> allowed to enter HTML.'),
  );
  
  $form['signit_sign_reciept'] = array(
    '#type' => 'checkbox',
    '#title' => t('Send reciept on signing.'),
    '#options' => array('Enabled'),
    '#default_value' => $signit['signit_sign_reciept'] ? 1 : 0,
    '#description' => t('Sends the user a message when they\'ve signed a SignIt.')
  );
  
  $form['signit_sign_reciept_subject'] = array(
    '#type'          => 'textarea',
    '#title'         => t('Signing email message subject'),
    '#default_value' => $signit['message'],
    '#description'   => t('Subject of auto-response email message to be sent to user when they sign a SignIt.'),
  );
  
  $form['signit_sign_reciept_message'] = array(
    '#type'          => 'textarea',
    '#title'         => t('Signing email message body'),
    '#default_value' => $signit['message'],
    '#description'   => t('Body of auto-response email message to be sent to user when they sign a SignIt.'),
  );
  
  return $form;
}
 
/* ******************************************** */
/* Target functions */
/* ******************************************** */

/**
 * implementation of the hook_signit_targets
 */
function signit_signit_targets($op, $data){
  switch ($op) {
    case 'admin':
      return signit_signit_targets_admin();
    break;
    case 'create':
      return signit_signit_targets_create($data);
  } 
}

/**
 * generates the form for hook_signit_targets
 */
function signit_signit_targets_create($signit){
  
  // set target title
  $form['signit_target_title'] = array(
    '#type' => 'textfield',
    '#title' => t('Target title'),
    '#default_value' => $node->signit['target_title'],
    '#description'   => t('Give the intended target of your SignIt a title.'),
    '#access' => variable_get('signit_target_title_set', false) ? true: false,
  );

  // build the potential targets from list
  $addresses = explode("\n", variable_get('signit_targets_default',''));
  // check all values to make sure we don't get any extra returns in
  foreach($addresses as $address) {
    $email = explode(',', $address);
    if ($address) {$items[$email[0]] = $email[1] ? $email[1] : $email[0]; }
  }

  // check the target settigns
  switch (variable_get('signit_targets_set', 0)) {
    
    case 0:
      $form['signit_targets_email_to'] = array(
        '#type' => 'hidden',
        '#default_value' => variable_get('signit_targets_default',''),
      );
    break;
    
    case 1:
      $form['signit_targets_email_to'] = array(
        '#type' => 'select',
        '#title' => t('SignIt email targets'),
        '#options' => $items,
        '#description' => t('Enter email address and name seperated by comma, eg: "janedoe@janedoe.com, Jane Doe". Names are not needed, but will replace the email address on the display. Please note, changes to this do not effect already collected signatures.'),
      );        
    break;
    
    case 2:
      $form['signit_targets_email_to'] = array(
        '#type' => 'textarea',
        '#title' => t('SignIt email targets'),
        '#default_value' => $items,
        '#description' => t('Enter email address and name seperated by comma, eg: "janedoe@janedoe.com, Jane Doe". Names are not needed, but will replace the email address on the display. Please note, changes to this do not effect already collected signatures.'),
      );
    break;
  }
  
  return $form;
}


/**
 * generates the form for hook_signit_targets for admin
 */
function signit_signit_targets_admin() {

  $form['signit_target_title_set'] = array(
    '#type' => 'checkbox',
    '#title' => t('SignIt creators can set the title of their signit'),
    '#default_value' => variable_get('signit_target_title_set', true),
    '#description' => t('This allows a SignIt creator to "name" a target or set of targets.'), 
  );
  
  $radios = array(
    0 => t('SignIt Creators can not select target'), 
    1 => t('SignIt Creators can select targets from a list'), 
    2 => t('SignIt Creators can enter their own targets')
  );
  $form['signit_targets_set'] = array(
    '#type' => 'select',
    '#title' => t('Target settings'),
    '#options' => $radios,
    '#default_value' => variable_get('signit_targets_set', 0),  
    '#description' => t('If SignIt creators can not select a target, the target(s) are used from the field below. If users can select from a list, that list is populated from the field below.'),
  );
  $form['signit_targets_default'] = array(
    '#type'          => 'textarea',
    '#title'         => t('SignIt email targets'),
    '#default_value' => variable_get('signit_targets_default',''),
    '#description'   => t('Enter email address and name seperated by comma, eg: "janedoe@janedoe.com, Jane Doe". Names are not needed, but will replace the email address on the display. Please note, changes to this do not effect already collected signatures.'),
  );
      
  return $form;  
}

/* ******************************************** */
/* Display Control functions */
/* ******************************************** */

/**
 * implementation of the hook_signit_control
 */
function signit_signit_control($op, $data = array()){
  switch ($op) {
    case 'admin':
      return signit_signit_control_admin();
    break;
    case 'create':
      return signit_signit_control_create($data);
  } 
}

/**
 * builds form for the admin settings page
 */
function signit_signit_control_admin() {
  $form['signit_display_enabled'] = array(
    '#type' => 'checkbox',
    '#title' => t('Show enabled box'),
    '#default_value' => variable_get('signit_display_enabled', true),
    '#description' => t('Allow SignIt creators to enable and disable their SignIts.'), 
  );
  
  $form['signit_display_date'] = array(
    '#type' => 'checkbox',
    '#title' => t('Show date ranges'),
    '#default_value' => variable_get('signit_display_date', true),
    '#description' => t('Allow SignIt creators to enable date ranges for their signits.'), 
  );
  
  return $form;
}

/**
 * builds form for the signit create
 */
function signit_signit_control_create($signit) {
  
  if (variable_get('signit_display_enabled', true)) {
    $form['signit_status'] = array(
      '#type' => 'checkbox',
      '#title' => t('This SignIt is enabled.'),
      '#options' => array('Enabled'),
      '#default_value' => $signit['status'] ? 1 : 0, 
      '#description' => t('If this is set, users may sign this node.'),
    );
  }
  else {
    $form['signit_status'] = array(
      '#type' => 'hidden',
      '#default_value' => $signit['status'], 
    );
  }
 
  if (variable_get('signit_display_date', true)) {
    $form['dates'] = array(
      '#type' => 'fieldset',
      '#title' => t('SignIt dates'),
      '#collapsible' => true,
    );
  
    $form['dates']['signit_use_dates'] = array(
      '#type' => 'checkbox',
      '#title' => t('Enable date control.'),
      '#options' => array('Enabled'),
      '#default_value' => $signit['use_dates'] ? 1 : 0, 
      '#description' => t('If this is set, users can only sign a SignIt between these dates. If this is not set, users can always add signatures.'),
    );
  
    $default_date = array('day' => format_date(time(), 'custom', 'j'),
      'month' => format_date(time(), 'custom', 'n'),
      'year' => format_date(time(), 'custom', 'Y')); 
  
    $form['dates']['signit_start'] = array(
      '#type' => 'date',
      '#title' => t('SignIt start'),
      '#description' => t('Date when the SignIt can be signed.'),
      '#prefix' => '<div id="signit_dates">',
      '#default_value' => $node->signit['start'] ? array(
        'day' => format_date($node->signit['start'], 'custom', 'j'),
        'month' => format_date($node->signit['start'], 'custom', 'n'),
        'year' => format_date($node->signit['start'], 'custom', 'Y')) : $default_date
    );
    
    $form['dates']['signit_end'] = array(
      '#type' => 'date',
      '#title' => t('SignIt end'),    
      '#description' => t('Date when the SignIt can no longer be signed.'),
      '#suffix' => '</div>',
      '#default_value' => $node->signit['end'] ? array(
        'day' => format_date($node->signit['end'], 'custom', 'j'),
        'month' => format_date($node->signit['end'], 'custom', 'n'),
        'year' => format_date($node->signit['end'], 'custom', 'Y')) : $default_date      
    );
  }
  else {
    $form['signit_status'] = array(
      '#type' => 'hidden',
      '#default_value' => $signit['status'], 
    );
  }
  
  
  return $form;
}


/* ******************************************** */
/* Signing functions */
/* ******************************************** */

/**
 * implementation of the hook_signit_sign
 * @param $op string that defines what operation to call
 * @param $form_values is the array of submitted form data
 * @param $signit is the signit array associated with this form
 */
function signit_signit_sign($op, $form_values = array(), $signit = array()){
  switch ($op) {
    case 'admin':
      return signit_sign_validate($form_values);
    break;
    case 'create':
      return signit_sign_sign($form_values);
  } 
}

/**
 * does validation for all the signit create form functions in this include file
 */
function signit_sign_validate($form_values) {
  
  // check email address
  if (! valid_email_address($form_values['user_email'])) {
    form_set_error('user_email', t('Please enter a valid email address'));
  }
  
  // check targets
  
  // check dates
  
  // check process  

}


/**
 * fires when a SignIt is signed
 * @param $signit is a signit array
 */
function signit_sign_sign ($form_values, $signit) {

  // check and see if we should send message to user
  if ($signit['signit_sign_reciept']) {
    drupal_mail('signit_sign_reciept', $signit['user_email'], $signit['signit_sign_reciept_subject'], $signit['signit_sign_reciept_message']);
  }
  
}
